@@ -20,8 +20,9 @@ from .stack_layout import StackFrame, StackLayout
 from .terminal import Terminal
 from .utils import is_selectable
 
-version = "1.4.6"
+version = "1.4.7"
 
+# TODO Backspace exit help
 # TODO support ctrl-a + (whatever emacs keybinding to go to end of line)
 #  https://www.gnu.org/software/bash/manual/html_node/Commands-For-Moving.html
 # TODO add () to text for builtin-methods
@@ -30,6 +31,7 @@ version = "1.4.6"
 # TODO move help into the overview layout
 # TODO truncate public/private -> pub priv -> just public/private
 # TODO truncate explorer subtitle as well
+# TODO +-_= to change the size of the explorer window
 # TODO auto return on q or r
 # TODO builtin frame/stack explorer? from objexplore import stackexplore
 # TODO filter color the filters the same as the explorer
@@ -48,10 +50,10 @@ class ObjExploreApp:
 
         self.cached_obj: CachedObject = cached_obj
         self.stack = StackLayout(head_obj=self.cached_obj, visible=False)
-        self.help_layout = HelpLayout(version, visible=False)
-        self.overview_layout = OverviewLayout()
+        self.help_layout = HelpLayout(version, visible=False, ratio=3)
+        self.explorer_layout = ExplorerLayout(cached_obj=cached_obj)
+        self.overview_layout = OverviewLayout(ratio=3)
         self.term = Terminal(stack=self.stack)
-        self.explorer_layout = ExplorerLayout(cached_obj=cached_obj, term=self.term)
         self.filter_layout = FilterLayout(term=self.term, visible=False)
 
         self.stack.append(
@@ -134,7 +136,7 @@ class ObjExploreApp:
 
         if self.help_layout.visible:
             # Close help page
-            if key == "?" or key.code in (self.term.KEY_ESCAPE, self.term.KEY_BACKSPACE):
+            if key == "?" or key.code == self.term.KEY_ESCAPE:
                 self.help_layout.visible = False
                 return
 
@@ -193,7 +195,7 @@ class ObjExploreApp:
             # TODO abstract the following
             if not is_selectable(new_cached_obj.obj):
                 return
-            self.explorer_layout = ExplorerLayout(cached_obj=new_cached_obj, term=self.term)
+            self.explorer_layout = ExplorerLayout(cached_obj=new_cached_obj)
             self.cached_obj = new_cached_obj
             self.cached_obj.cache()
             self.filter_layout.cancel_search(self.cached_obj)
@@ -282,7 +284,7 @@ class ObjExploreApp:
             if not is_selectable(new_cached_obj.obj):
                 return
 
-            self.explorer_layout = ExplorerLayout(cached_obj=new_cached_obj, term=self.term)
+            self.explorer_layout = ExplorerLayout(cached_obj=new_cached_obj)
             self.cached_obj = new_cached_obj
             self.cached_obj.cache()
             self.filter_layout.cancel_search(self.cached_obj)
@@ -294,15 +296,6 @@ class ObjExploreApp:
                 )
             )
 
-        elif key == "+":
-            self.term.increase_explorer_size()
-
-        elif key in ("-", "_"):
-            self.term.decrease_explorer_size()
-
-        elif key == "=":
-            self.term.explorer_size_extra = 0
-
         # Go back to parent
         elif (key == "h" or key.code == self.term.KEY_LEFT) and self.stack.stack:
             self.stack.pop()
