@@ -1,8 +1,5 @@
-
 def is_selectable(obj):
     try:
-        bool(obj)
+        return obj not in (None, [], (), {}, set())
     except ValueError:
         return True
-    else:
-        return obj not in (None, [], (), {}, set())
